@@ -840,11 +840,13 @@ class DeploymentSettingAssembler(Assembler):
             volumes = None if dto.volumes is None else [volume_setting_assembler.to_entity(i) for i in dto.volumes],
             selector = label_selector_assembler.to_entity(dto.selector),
             dns_policy = None if dto.dns_policy is None else DNSPolicy(dto.dns_policy),
-            service_account_name = None if dto.service_account_name is None else ServiceAccountName(dto.service_account_name)
+            service_account_name = None if dto.service_account_name is None else ServiceAccountName(dto.service_account_name),
+            node_affinity=None if dto.node_affinity is None else [node_affinity_assembler.to_entity(m) for m in dto.node_affinity]
         )
 deployment_setting_assembler = DeploymentSettingAssembler()
     
 
+
 class JobSettingAssembler(Assembler):
     def to_entity(self, dto: JobSettingDTO):
         return JobSetting(
@@ -862,7 +864,8 @@ class JobSettingAssembler(Assembler):
             volumes = None if dto.volumes is None else [volume_setting_assembler.to_entity(i) for i in dto.volumes],
             selector = None if dto.selector is None else label_selector_assembler.to_entity(dto.selector),
             dns_policy = None if dto.dns_policy is None else DNSPolicy(dto.dns_policy),
-            service_account_name = None if dto.service_account_name is None else ServiceAccountName(dto.service_account_name)
+            service_account_name = None if dto.service_account_name is None else ServiceAccountName(dto.service_account_name),
+            node_affinity=None if dto.node_affinity is None else [node_affinity_assembler.to_entity(m) for m in dto.node_affinity]
         )
 
 class JobAssembler(Assembler):
