@@ -137,7 +137,8 @@ class NodeUserSetting(Entity):
         if amount.get_value() > 1:
             self.postfix = Bool(True)
             self.add_postfix()
-            self.name = NodeName(self.name.get_value()+'-')
+            # self.name = NodeName(self.name.get_value()+'-')
+            print('node name:', self.name.get_value())
         else:
             self.add_postfix()
     
@@ -266,7 +267,7 @@ class NodeCreationItem(ExpiredEntity):
         self._life_time = _life_time
         super().__init__(_life_time=_life_time)
 
-    def is_sending_timeout(self, timeout=30):
+    def is_sending_timeout(self, timeout=600):
         if self.status.is_sent():
             diff = datetime.datetime.utcnow()-self.status.changed_time
             return diff.seconds>timeout
@@ -677,77 +678,6 @@ class ContainerSetting(Entity):
         self.ports = ports
 
 
-class DeploymentSetting(Entity):
-    def __init__(
-        self,
-        deployment_name: Name,
-        namespace_name: Name,
-        labels: LabelDict,
-        containers: List[ContainerSetting],
-        init_containers: Optional[List[ContainerSetting]],
-        node_name: Optional[Name],
-        node_selector: Optional[NodeSelectorDict],
-        replicas: Optional[Number],
-        restart_policy: Optional[RestartPolicy],
-        volumes: Optional[List[VolumeSetting]],
-        selector: LabelSelector,
-        dns_policy: Optional[DNSPolicy],
-        service_account_name: Optional[ServiceAccountName] = None
-    ) -> None:
-        self.deployment_name = deployment_name
-        self.namespace_name = namespace_name
-        self.labels = labels
-        self.containers = containers
-        self.init_containers = init_containers
-        self.node_name = node_name
-        self.node_selector = node_selector
-        self.replicas = replicas
-        self.restart_policy = restart_policy
-        self.volumes = volumes
-        self.selector = selector
-        self.dns_policy = dns_policy
-        self.service_account_name = service_account_name
-
-
-
-class JobSetting(Entity):
-    def __init__(
-        self,
-        job_name: Name,
-        namespace_name: Name,
-        labels: LabelDict,
-        containers: List[ContainerSetting],
-        init_containers: Optional[List[ContainerSetting]],
-        parallelism: Number = Number(1),
-        ttl_seconds_after_finished: Number = Number(600),
-        restart_policy: RestartPolicy = RestartPolicy('Never'),
-        backoff_limit: Number = Number(2),
-        node_name: Optional[Name] = None,
-        node_selector: Optional[NodeSelectorDict] = None,
-        volumes: Optional[List[VolumeSetting]] = None,
-        selector: Optional[LabelSelector] = None,
-        dns_policy: Optional[DNSPolicy] = None,
-        service_account_name: Optional[ServiceAccountName] = None
-    ):
-        self.job_name = job_name
-        self.namespace_name = namespace_name
-        self.labels = labels
-        self.containers = containers
-        self.init_containers = init_containers
-        self.parallelism = parallelism
-        self.ttl_seconds_after_finished = ttl_seconds_after_finished
-        if restart_policy is None:
-            self.restart_policy = RestartPolicy('Never')
-        else:
-            self.restart_policy = restart_policy
-        self.backoff_limit = backoff_limit
-        self.node_name = node_name
-        self.node_selector = node_selector
-        self.volumes = volumes
-        self.selector = selector
-        self.dns_policy = dns_policy
-        self.service_account_name = service_account_name
-
 class Job(ExpiredEntity):
     def __init__(
         self,
@@ -911,4 +841,82 @@ class DatapipeDataInfo(Entity):
         return self.__dict__
 
 class DatapipeResponse(CommandResponse):
-    pass
\ No newline at end of file
+    pass
+
+
+
+class DeploymentSetting(Entity):
+    def __init__(
+        self,
+        deployment_name: Name,
+        namespace_name: Name,
+        labels: LabelDict,
+        containers: List[ContainerSetting],
+        init_containers: Optional[List[ContainerSetting]],
+        node_name: Optional[Name],
+        node_selector: Optional[NodeSelectorDict],
+        replicas: Optional[Number],
+        restart_policy: Optional[RestartPolicy],
+        volumes: Optional[List[VolumeSetting]],
+        selector: LabelSelector,
+        dns_policy: Optional[DNSPolicy],
+        service_account_name: Optional[ServiceAccountName] = None,
+        node_affinity: Optional[NodeAffinity] = None
+    ) -> None:
+        self.deployment_name = deployment_name
+        self.namespace_name = namespace_name
+        self.labels = labels
+        self.containers = containers
+        self.init_containers = init_containers
+        self.node_name = node_name
+        self.node_selector = node_selector
+        self.replicas = replicas
+        self.restart_policy = restart_policy
+        self.volumes = volumes
+        self.selector = selector
+        self.dns_policy = dns_policy
+        self.service_account_name = service_account_name
+        self.node_affinity = node_affinity
+
+
+
+class JobSetting(Entity):
+    def __init__(
+        self,
+        job_name: Name,
+        namespace_name: Name,
+        labels: LabelDict,
+        containers: List[ContainerSetting],
+        init_containers: Optional[List[ContainerSetting]],
+        parallelism: Number = Number(1),
+        ttl_seconds_after_finished: Number = Number(600),
+        restart_policy: RestartPolicy = RestartPolicy('Never'),
+        backoff_limit: Number = Number(2),
+        node_name: Optional[Name] = None,
+        node_selector: Optional[NodeSelectorDict] = None,
+        volumes: Optional[List[VolumeSetting]] = None,
+        selector: Optional[LabelSelector] = None,
+        dns_policy: Optional[DNSPolicy] = None,
+        service_account_name: Optional[ServiceAccountName] = None,
+        node_affinity: Optional[NodeAffinity] = None
+    ):
+        self.job_name = job_name
+        self.namespace_name = namespace_name
+        self.labels = labels
+        self.containers = containers
+        self.init_containers = init_containers
+        self.parallelism = parallelism
+        self.ttl_seconds_after_finished = ttl_seconds_after_finished
+        if restart_policy is None:
+            self.restart_policy = RestartPolicy('Never')
+        else:
+            self.restart_policy = restart_policy
+        self.backoff_limit = backoff_limit
+        self.node_name = node_name
+        self.node_selector = node_selector
+        self.volumes = volumes
+        self.selector = selector
+        self.dns_policy = dns_policy
+        self.service_account_name = service_account_name
+        self.node_affinity = node_affinity
+
