@@ -100,7 +100,7 @@ class K3SController:
         self._check_error(response.status_code, infos)
         return [NodeMetaDO(**meta) for meta in infos]
 
-    def add_node_label(self, node_name: str, key: str, value: str, timeout=3):
+    def add_node_label(self, node_name: str, key: str, value: str, timeout=3)->bool:
         response=requests.post(f'{self.url}/label/node_name/{node_name}/key/{key}/value/{value}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
