@@ -837,7 +837,7 @@ label_selector_requirement_converter = LabelSelectorRequirementConverter()
 class LabelSelectorConverter(Converter):
     def to_entity(self, do: LabelSelectorDO):
         return LabelSelector(
-            match_labels = MatchLabels(do.match_labels),
+            match_labels = None if do.match_labels is None else MatchLabels(do.match_labels),
             match_expressions= None if do.match_expressions is None else [label_selector_requirement_converter.to_entity(i) for i in do.match_expressions]
         )
     def to_do(self, x: LabelSelector):
@@ -918,7 +918,8 @@ class DeploymentSettingConverter(Converter):
             volumes = None if do.volumes is None else [volume_setting_converter.to_entity(i) for i in do.volumes],
             selector = label_selector_converter.to_entity(do.selector),
             dns_policy = None if do.dns_policy is None else DNSPolicy(do.dns_policy),
-            service_account_name = None if do.service_account_name is None else ServiceAccountName(do.service_account_name)
+            service_account_name = None if do.service_account_name is None else ServiceAccountName(do.service_account_name),
+            node_affinity = None if do.node_affinity is None else [node_affinity_converter.to_entity(m) for m in do.node_affinity]
         )
     def to_do(self, x: DeploymentSetting):
         return DeploymentSettingDO(
@@ -934,7 +935,8 @@ class DeploymentSettingConverter(Converter):
             volumes=None if x.volumes is None else [volume_setting_converter.to_do(m) for m in x.volumes],
             selector = label_selector_converter.to_do(x.selector),
             dns_policy=None if x.dns_policy is None else x.dns_policy.get_value(),
-            service_account_name=None if x.service_account_name is None else ServiceAccountName(x.service_account_name)
+            service_account_name=None if x.service_account_name is None else ServiceAccountName(x.service_account_name),
+            node_affinity=None if x.node_affinity is None else [node_affinity_converter.to_do(m) for m in x.node_affinity]
         )
 deployment_setting_converter = DeploymentSettingConverter()
 
@@ -955,7 +957,8 @@ class JobSettingConverter(Converter):
             volumes=None if do.volumes is None else [volume_setting_converter.to_entity(m) for m in do.volumes],
             selector=None if do.selector is None else [label_selector_converter.to_entity(m) for m in do.selector],
             dns_policy=None if do.dns_policy is None else DNSPolicy(do.dns_policy),
-            service_account_name=None if do.service_account_name is None else ServiceAccountName(do.service_account_name)
+            service_account_name=None if do.service_account_name is None else ServiceAccountName(do.service_account_name),
+            node_affinity = None if do.node_affinity is None else [node_affinity_converter.to_entity(m) for m in do.node_affinity]
 
         )
     def to_do(self, x: JobSetting):
@@ -974,7 +977,8 @@ class JobSettingConverter(Converter):
             volumes = None if x.volumes is None else [volume_setting_converter.to_do(i) for i in x.volumes],
             selector = None if x.selector is None else [label_selector_converter.to_do(i) for i in x.selector],
             dns_policy = None if x.dns_policy is None else x.dns_policy.get_value(),
-            service_account_name = None if x.service_account_name is None else x.service_account_name.get_value()
+            service_account_name = None if x.service_account_name is None else x.service_account_name.get_value(),
+            node_affinity=None if x.node_affinity is None else [node_affinity_converter.to_do(m) for m in x.node_affinity]
         )
 job_setting_converter = JobSettingConverter()
 
