@@ -305,39 +305,6 @@ class ContainerSettingDO(BaseModel):
     ports: Optional[List[ContainerPortDO]] = None
 
 
-class DeploymentSettingDO(BaseModel):
-    deployment_name: str
-    namespace_name: str
-    labels: Dict
-    containers: List[ContainerSettingDO]
-    init_containers: Optional[List[ContainerSettingDO]] = None
-    node_name: Optional[str] = None
-    node_selector: Optional[Dict] = None
-    replicas: Optional[int] = None
-    restart_policy: Optional[str] = None
-    volumes: Optional[List[VolumeSettingDO]] = None
-    selector: LabelSelectorDO
-    dns_policy: Optional[str] = None
-    service_account_name: Optional[str] = None
-
-
-
-class JobSettingDO(BaseModel):
-    job_name: str
-    namespace_name: str
-    labels: Dict
-    containers: List[ContainerSettingDO]
-    init_containers: Optional[List[ContainerSettingDO]]
-    node_name: Optional[str] = None
-    node_selector: Optional[Dict] = None
-    parallelism: Optional[int] = 1
-    ttl_seconds_after_finished: Optional[int] = 600
-    restart_policy: Optional[str] = 'Never'
-    backoff_limit: Optional[int] = 2
-    volumes: Optional[List[VolumeSettingDO]] = None
-    selector: Optional[LabelSelectorDO] = None
-    dns_policy: Optional[str] = None
-    service_account_name: Optional[str] = None
 
 
 class JobDO(BaseModel):
@@ -424,3 +391,42 @@ class DatapipeDataInfoDO(BaseModel):
 
 class DatapipeResponseDO(CommandResponseDO):
     pass
+
+
+
+class DeploymentSettingDO(BaseModel):
+    deployment_name: str
+    namespace_name: str
+    labels: Dict
+    containers: List[ContainerSettingDO]
+    init_containers: Optional[List[ContainerSettingDO]] = None
+    node_name: Optional[str] = None
+    node_selector: Optional[Dict] = None
+    replicas: Optional[int] = None
+    restart_policy: Optional[str] = None
+    volumes: Optional[List[VolumeSettingDO]] = None
+    selector: LabelSelectorDO = None
+    dns_policy: Optional[str] = None
+    service_account_name: Optional[str] = None
+    node_affinity: Optional[List[NodeAffinityDO]]=None
+
+
+
+class JobSettingDO(BaseModel):
+    job_name: str
+    namespace_name: str
+    labels: Dict
+    containers: List[ContainerSettingDO]
+    init_containers: Optional[List[ContainerSettingDO]]
+    node_name: Optional[str] = None
+    node_selector: Optional[Dict] = None
+    parallelism: Optional[int] = 1
+    ttl_seconds_after_finished: Optional[int] = 600
+    restart_policy: Optional[str] = 'Never'
+    backoff_limit: Optional[int] = 2
+    volumes: Optional[List[VolumeSettingDO]] = None
+    selector: Optional[LabelSelectorDO] = None
+    dns_policy: Optional[str] = None
+    service_account_name: Optional[str] = None
+    node_affinity: Optional[List[NodeAffinityDO]]=None
+
